==> facmgr_install_1.0.1_0214.tar.bz2: facmgr_install/mpd.sql <==
CREATE TABLE `buckets`  (
    `bucketname` varchar(255) NOT NULL DEFAULT '',
    `id` varchar(255) DEFAULT NULL,
    `usages` bigint(20) DEFAULT NULL,
    `acl` JSON DEFAULT NULL,
    `cors` JSON DEFAULT NULL,
    `lc` JSON DEFAULT NULL,
    `uid` varchar(255) DEFAULT NULL,
    `policy` JSON DEFAULT NULL,
    `website` JSON DEFAULT NULL,
    `createtime` datetime DEFAULT NULL,
    `versioning` varchar(255) DEFAULT NULL
);
CREATE TABLE `gc` (
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `version` bigint(20)  DEFAULT NULL,
    `location` varchar(255) DEFAULT NULL,
    `pool` varchar(255) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `status` varchar(255) DEFAULT NULL,
    `mtime` datetime DEFAULT NULL,
    `part` tinyint(1) DEFAULT NULL,
    `triedtimes` int(11) DEFAULT NULL
);
CREATE TABLE `gcpart` (
    `partnumber` int(11) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `offset` bigint(20) DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `lastmodified` datetime DEFAULT NULL,
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `version` bigint(20)  DEFAULT NULL
);
CREATE TABLE `multipartpart` (
    `partnumber` int(11) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `offset` bigint(20) DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `lastmodified` datetime DEFAULT NULL,
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `fileId` varchar(255) DEFAULT NULL,
    `uploadtime` text  DEFAULT ""
);
CREATE TABLE `multiparts` (
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `uploadtime` text  DEFAULT "",
    `initiatorid` varchar(255) DEFAULT NULL,
    `ownerid` varchar(255) DEFAULT NULL,
    `contenttype` varchar(255) DEFAULT NULL,
    `attrs` text  DEFAULT "",
    `category` tinyint(1) DEFAULT 0,
    `tags`  varchar(255) DEFAULT  NULL,
     `fileId` varchar(255) DEFAULT NULL
);
CREATE TABLE `objectpart` (
    `partnumber` int(11) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `offset` bigint(20) DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `lastmodified` datetime DEFAULT NULL,
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `ownerid` varchar(255) DEFAULT NULL,
    `fileId` varchar(255) DEFAULT NULL,
    `version` varchar(255) DEFAULT NULL
);
CREATE TABLE `objects` (
    `bucketname` varchar(255) DEFAULT NULL,
    `name` varchar(1024) DEFAULT NULL,
    `version` varchar(255)  DEFAULT NULL,
    `ownerid` varchar(255) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `lastmodifiedtime` datetime DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `cid` varchar(255) DEFAULT NULL,
    `contenttype` varchar(255) DEFAULT NULL,
    `deletemarker` tinyint(1) DEFAULT NULL,
    `type` tinyint(1) DEFAULT 0,
    `cidpending` bool DEFAULT true,
    `ispin` bool DEFAULT  false,
    `iscyfs` bool DEFAULT  false,
    `pinexp` datetime DEFAULT NULL,
    `cyfsexp` datetime DEFAULT NULL,
    `oodid`  varchar(255) DEFAULT  NULL,
    `fileid` varchar(255) DEFAULT  NULL,
    `ispersistent` bool DEFAULT  false,
    `thumb` varchar(255) DEFAULT NULL,
    `category` tinyint(1) DEFAULT 0,
    `tags`  varchar(255) DEFAULT  NULL,
    `merkleroot`  varchar(255) DEFAULT NULL,
    `updatedBy` varchar(255) DEFAULT NULL,
    `chunkCount` int DEFAULT 0,
    `nft_info` JSON DEFAULT NULL,
    `pinning` JSON DEFAULT NULL,
    `image_info` JSON DEFAULT NULL,
    `cars` varchar(255) DEFAULT NULL,
    `blocks` bigint(20) DEFAULT NULL
, attr JSON DEFAULT NULL);
CREATE TABLE `pinning` (
    `id` varchar(255) DEFAULT NULL,
    `requestId` varchar(255) DEFAULT NULL,
    `userId` varchar(255) DEFAULT NULL,
    `bucket` varchar(255) DEFAULT NULL,
    `origins` JSON DEFAULT NULL,
    `delegates` JSON DEFAULT NULL,
    `pinner` JSON DEFAULT NULL,
    `fstype` int default 0,
    `bucketData` JSON DEFAULT NULL,
    `meta` JSON DEFAULT NULL,
    `name` varchar(1024) DEFAULT NULL,
    `cid` varchar(255) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL,
    `updatedBy`  varchar(255) DEFAULT NULL,
    `status` varchar(25) DEFAULT NULL,
    `operType` int DEFAULT 0);
CREATE TABLE `event` (
    `id` varchar(255) DEFAULT NULL,
    `storageProviderId` varchar(255) DEFAULT NULL,
    `pinningID` varchar(255) DEFAULT NULL,
    `args` JSON DEFAULT NULL,
    `state` int default 0,
    `action`  varchar(255) DEFAULT NULL,
    `rootCid` varchar(255) DEFAULT NULL,
    `duration` int64 default  0,
    `timeToFirstByte` int64 default  0,
    `PinnedTime` int64 default  0,
    `averageSpeed` int64 default  0,
    `size` int64 default  0,
    `blocks` int64 default  0,
    `bucketData` JSON DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `retries` int default 0,
    `updatedTime` datetime DEFAULT NULL
, idx int DEFAULT 0);
CREATE TABLE `backend_access` (
    `key` varchar(255) DEFAULT NULL,
    `accessKey` varchar(128) DEFAULT NULL,
    `secretKey` varchar(128) DEFAULT NULL,
    `state` tinyint(1) DEFAULT 0,
    `createdTime` datetime DEFAULT NULL,
    `updatedTime` datetime DEFAULT NULL
    );
CREATE TABLE `backend` (
    `id` varchar(255) DEFAULT NULL,
    `endpoint` varchar(255) DEFAULT NULL,
    `bucket` varchar(255) DEFAULT NULL,
    `sizeInBytes` bigint(20) DEFAULT NULL,
    `usedInBytes` bigint(20) DEFAULT NULL,
    `remainInBytes` bigint(20) DEFAULT NULL,
    `state` tinyint(1) DEFAULT 0,
    `isDomain` bool,
    `isAutoEncrypt` bool,
    `weight` tinyint(1) DEFAULT 0,
    `createdTime` datetime DEFAULT NULL,
    `updatedTime` datetime DEFAULT NULL
    );
CREATE TABLE `file_chunks`(
    `chunkId` varchar(255) DEFAULT NULL,
    `fileVersionId` varchar(255) DEFAULT NULL,
    `idx` int(1) DEFAULT 0,
    `partId` int(1) DEFAULT 0,
    `nextChunkId`  varchar(255) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL
    );
CREATE TABLE `chunks` (
    `chunkId` varchar(255) DEFAULT NULL,
    `location` varchar(255) DEFAULT NULL,
    `sizeInBytes` bigint(20) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL ,
    `updatedBy`  varchar(255) DEFAULT NULL,
    `state` tinyint(1) DEFAULT 0,
    `acl` JSON DEFAULT NULL
    );
CREATE TABLE `extract_codes` (
  `code` TEXT NOT NULL PRIMARY KEY,
  `cid` TEXT NOT NULL,
 `expTime` DATETIME NOT NULL,
  `createdTime`  datetime DEFAULT NULL,
  `updatedTime`  datetime DEFAULT NULL,
  `updatedBy`  varchar(255) DEFAULT NULL
);

create table if not exists  `sync_fileinfo` (
    `hashkey` varchar(255) DEFAULT NULL,
    `name` varchar(1024) DEFAULT NULL,
    `folder_id`  varchar(255) DEFAULT NULL,
    `device_id` varchar(255) DEFAULT NULL,
    `size`  int64 default  0,
    `modified_s`  int64 default  0,
    `modified_by` varchar(255) DEFAULT NULL,
    `version` varchar(255)  DEFAULT NULL,
    `sequence` int64 default  0,
    `symlink_target` TEXT,
    `cid` varchar(255) DEFAULT NULL,
    `block_size` int32 default 0,
    `local_flags` int32 default 0,
    `deleted` int default 0,
    `invalid` int default 0,
    `content_type` varchar(255) DEFAULT NULL,
    `status` tinyint(1) DEFAULT 0,
    `chunks` JSON DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL

);
create table if not exists  `syncthing_folder` (
    `folderName`  varchar(1024) DEFAULT NULL,
    `folderId` varchar(255) DEFAULT NULL,
    `devices` JSON DEFAULT NULL,
    `snap` JSON DEFAULT NULL,
    `updatedBy`  varchar(255) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL,
    `userId` varchar(255) DEFAULT NULL,
    `fileSize` int64 default  0,
    `fileCount` int32 default 0,
    `paused` int default 0,
    `sequence` int64 default  0,
    `state` TEXT,
    `isDeleted` int,
    `failedEvents` TEXT
);

create table if not exists `userinfo` (
                          id INTEGER PRIMARY KEY AUTOINCREMENT, -- 替换 SERIAL，使用 SQLite 的自动递增主键
                          username TEXT NOT NULL, -- 替换 character varying
                          email TEXT, -- 替换 character varying
                          provider TEXT, -- 替换 character varying
                          is_active BOOLEAN DEFAULT 1, -- SQLite 中使用 1/0 表示布尔值
                          is_deleted BOOLEAN DEFAULT 0,
                          last_login DATETIME DEFAULT CURRENT_TIMESTAMP, -- 替换 timestamp without time zone
                          last_peer TEXT, -- 替换 character varying
                          ipv4 TEXT, -- 替换 character varying
                          ipv6 TEXT, -- 替换 character varying
                          is_online BOOLEAN DEFAULT 0,
                          quota bigint(20),
                          state int,
                          create_ts DATETIME DEFAULT CURRENT_TIMESTAMP,
                          update_ts DATETIME DEFAULT CURRENT_TIMESTAMP
);
create table if not exists `apikey` (
                        id INTEGER PRIMARY KEY AUTOINCREMENT, -- 替换 SERIAL
                        user_id INTEGER NOT NULL, -- 外键建议后续添加
                        hash BLOB, -- 替换 BYTEA
                        prefix TEXT, -- 替换 varchar(48)
                        key TEXT,
                        expiration DATETIME, -- 替换 TIMESTAMPTZ
                        create_ts DATETIME DEFAULT CURRENT_TIMESTAMP,
                        update_ts DATETIME DEFAULT CURRENT_TIMESTAMP
);

==> facmgr_install_1.0.1_1225.tar.bz2: facmgr_install/mpd.sql <==
CREATE TABLE IF NOT EXISTS `buckets`  (
    `bucketname` varchar(255) NOT NULL DEFAULT '',
    `id` varchar(255) DEFAULT NULL,
    `usages` bigint(20) DEFAULT NULL,
    `acl` JSON DEFAULT NULL,
    `cors` JSON DEFAULT NULL,
    `lc` JSON DEFAULT NULL,
    `uid` varchar(255) DEFAULT NULL,
    `policy` JSON DEFAULT NULL,
    `website` JSON DEFAULT NULL,
    `createtime` datetime DEFAULT NULL,
    `versioning` varchar(255) DEFAULT NULL
);
CREATE TABLE IF NOT EXISTS `gc` (
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `version` bigint(20)  DEFAULT NULL,
    `location` varchar(255) DEFAULT NULL,
    `pool` varchar(255) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `status` varchar(255) DEFAULT NULL,
    `mtime` datetime DEFAULT NULL,
    `part` tinyint(1) DEFAULT NULL,
    `triedtimes` int(11) DEFAULT NULL
);

CREATE TABLE IF NOT EXISTS`gcpart` (
    `partnumber` int(11) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `offset` bigint(20) DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `lastmodified` datetime DEFAULT NULL,
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `version` bigint(20)  DEFAULT NULL
);

CREATE TABLE IF NOT EXISTS `multipartpart` (
    `partnumber` int(11) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `offset` bigint(20) DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `lastmodified` datetime DEFAULT NULL,
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `fileId` varchar(255) DEFAULT NULL,
    `uploadtime` text  DEFAULT ""
);

CREATE TABLE IF NOT EXISTS `multiparts` (
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `uploadtime` text  DEFAULT "",
    `initiatorid` varchar(255) DEFAULT NULL,
    `ownerid` varchar(255) DEFAULT NULL,
    `contenttype` varchar(255) DEFAULT NULL,
    `attrs` text  DEFAULT "",
    `category` tinyint(1) DEFAULT 0,
    `tags`  varchar(255) DEFAULT  NULL,
     `fileId` varchar(255) DEFAULT NULL
);

CREATE TABLE IF NOT EXISTS `objectpart` (
    `partnumber` int(11) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `offset` bigint(20) DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `lastmodified` datetime DEFAULT NULL,
    `bucketname` varchar(255) DEFAULT NULL,
    `objectname` varchar(255) DEFAULT NULL,
    `ownerid` varchar(255) DEFAULT NULL,
    `fileId` varchar(255) DEFAULT NULL,
    `version` varchar(255) DEFAULT NULL
);
CREATE TABLE IF NOT EXISTS `objects` (
    `bucketname` varchar(255) DEFAULT NULL,
    `name` varchar(1024) DEFAULT NULL,
    `version` varchar(255)  DEFAULT NULL,
    `ownerid` varchar(255) DEFAULT NULL,
    `size` bigint(20) DEFAULT NULL,
    `objectid` varchar(255) DEFAULT NULL,
    `lastmodifiedtime` datetime DEFAULT NULL,
    `etag` varchar(255) DEFAULT NULL,
    `cid` varchar(255) DEFAULT NULL,
    `contenttype` varchar(255) DEFAULT NULL,
    `deletemarker` tinyint(1) DEFAULT NULL,
    `type` tinyint(1) DEFAULT 0,
    `cidpending` bool DEFAULT true,
    `ispin` bool DEFAULT  false,
    `iscyfs` bool DEFAULT  false,
    `pinexp` datetime DEFAULT NULL,
    `cyfsexp` datetime DEFAULT NULL,
    `oodid`  varchar(255) DEFAULT  NULL,
    `fileid` varchar(255) DEFAULT  NULL,
    `ispersistent` bool DEFAULT  false,
    `thumb` varchar(255) DEFAULT NULL,
    `category` tinyint(1) DEFAULT 0,
    `tags`  varchar(255) DEFAULT  NULL,
    `merkleroot`  varchar(255) DEFAULT NULL,
    `updatedBy` varchar(255) DEFAULT NULL,
    `chunkCount` int DEFAULT 0,
    `nft_info` JSON DEFAULT NULL,
    `pinning` JSON DEFAULT NULL,
    `image_info` JSON DEFAULT NULL,
    `cars` varchar(255) DEFAULT NULL,
    `blocks` bigint(20) DEFAULT NULL
);


create table if not exists `pinning` (
    `id` varchar(255) DEFAULT NULL,
    `requestId` varchar(255) DEFAULT NULL,
    `userId` varchar(255) DEFAULT NULL,
    `bucket` varchar(255) DEFAULT NULL,
    `origins` JSON DEFAULT NULL,
    `delegates` JSON DEFAULT NULL,
    `pinner` JSON DEFAULT NULL,
    `fstype` int default 0,
    `bucketData` JSON DEFAULT NULL,
    `meta` JSON DEFAULT NULL,
    `name` varchar(1024) DEFAULT NULL,
    `cid` varchar(255) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL,
    `updatedBy`  varchar(255) DEFAULT NULL,
    `status` varchar(25) DEFAULT NULL

    );

create table if not exists  `event` (
    `id` varchar(255) DEFAULT NULL,
    `storageProviderId` varchar(255) DEFAULT NULL,
    `pinningID` varchar(255) DEFAULT NULL,
    `args` JSON DEFAULT NULL,
    `state` int default 0,
    `action`  varchar(255) DEFAULT NULL,
    `rootCid` varchar(255) DEFAULT NULL,
    `duration` int64 default  0,
    `timeToFirstByte` int64 default  0,
    `PinnedTime` int64 default  0,
    `averageSpeed` int64 default  0,
    `size` int64 default  0,
    `blocks` int64 default  0,
    `bucketData` JSON DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `retries` int default 0,
    `updatedTime` datetime DEFAULT NULL
);
create table if not exists `backend_access` (
    `key` varchar(255) DEFAULT NULL,
    `accessKey` varchar(128) DEFAULT NULL,
    `secretKey` varchar(128) DEFAULT NULL,
    `state` tinyint(1) DEFAULT 0,
    `createdTime` datetime DEFAULT NULL,
    `updatedTime` datetime DEFAULT NULL
    );

create table if not exists `backend` (
    `id` varchar(255) DEFAULT NULL,
    `endpoint` varchar(255) DEFAULT NULL,
    `bucket` varchar(255) DEFAULT NULL,
    `sizeInBytes` bigint(20) DEFAULT NULL,
    `usedInBytes` bigint(20) DEFAULT NULL,
    `remainInBytes` bigint(20) DEFAULT NULL,
    `state` tinyint(1) DEFAULT 0,
    `isDomain` bool,
    `isAutoEncrypt` bool,
    `weight` tinyint(1) DEFAULT 0,
    `createdTime` datetime DEFAULT NULL,
    `updatedTime` datetime DEFAULT NULL
    );


create table if not exists `file_chunks`(
    `chunkId` varchar(255) DEFAULT NULL,
    `fileVersionId` varchar(255) DEFAULT NULL,
    `idx` int(1) DEFAULT 0,
    `nextChunkId`  varchar(255) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL
    );
create table if not exists `chunks` (
    `chunkId` varchar(255) DEFAULT NULL,
    `location` varchar(255) DEFAULT NULL,
    `sizeInBytes` bigint(20) DEFAULT NULL,
    `createdTime`  datetime DEFAULT NULL,
    `updatedTime`  datetime DEFAULT NULL,
    `updatedBy`  varchar(255) DEFAULT NULL,
    `state` tinyint(1) DEFAULT 0,
    `acl` JSON DEFAULT NULL
    );
